==> haskell-emojis-0.1.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 emojis
version:              0.1.2
visibility:           public
id:                   emojis-0.1.2-3hcHsPqy0kd1wz0wi4f1T8
key:                  emojis-0.1.2-3hcHsPqy0kd1wz0wi4f1T8
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  cfb23b56393d36b7ad131d67df48c5c0
exposed:              True
exposed-modules:      Text.Emoji
import-dirs:          /usr/lib/ghc-9.0.2/site-local/emojis-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/emojis-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.2-3hcHsPqy0kd1wz0wi4f1T8
depends:              base-4.15.1.0 containers-0.6.4.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-emojis-0.1.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 emojis
version:              0.1.2
visibility:           public
id:                   emojis-0.1.2-HYiXDTkm1qCKHL8IMQ0Eoc
key:                  emojis-0.1.2-HYiXDTkm1qCKHL8IMQ0Eoc
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  c494b5c16b33be810f2a96be0be1a7b6
exposed:              True
exposed-modules:      Text.Emoji
import-dirs:          /usr/lib/ghc-9.0.2/site-local/emojis-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/emojis-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.2-HYiXDTkm1qCKHL8IMQ0Eoc
depends:              base-4.15.1.0 containers-0.6.4.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
